iamai.adapter.gensokyo package
==============================

Submodules
----------

.. toctree::
   :maxdepth: 4

   iamai.adapter.gensokyo.config
   iamai.adapter.gensokyo.event
   iamai.adapter.gensokyo.exceptions
   iamai.adapter.gensokyo.message

Module contents
---------------

.. automodule:: iamai.adapter.gensokyo
   :members:
   :undoc-members:
   :show-inheritance:
